# Silicon - MF WFN - PARATEC

In this directory we perform a non-self-consistent (NSCF) mean-field calculation to
generate all of the Bloch states needed for the subsequent GW calculations. 
The resulting wavefunction file will then be read as `WFN` by the Epsilon code,
and `WFN_inner` by the Sigma code.

Follow these steps:

1. Run `sbatch --reservation=vESW_2020_Fri ./02-calculate_wfn.run` to calculate
   the wavefunctions with PARATEC.

2. Take a look at the input file `kgrid.inp` for `kgrid.x`, the executable that
   generates our k-grids for NSCF calculations. Compare this input file with
   the documentation available at http://manual.berkeleygw.org/2.1/kgrid/.
   What is the meaning of each field?
   How many k-points do you expect to be generated? Find the FFT grid in the
   PARATEC output file in `1-scf` and check that it is correct in `kgrid.inp`.
   Why do we need this? What happens if you use a different value (e.g. an odd
   one)?  How does the kgrid used here compare to that in `1-scf`?

3. Run `./01-get_kgrid.sh` to generate the k-grid. Take a look at the output
   output `kgrid.out` and the more verbose log `kgrid.log`.
   - What is the space group?
   - What are the symmetry elements of the crystal?
   - What k-grid was generated?
   - How many k-points are there in the full and symmetry-folded Brillouin zone?
   - See what symmetry operation was used to relate two points in the full BZ and
     reduce them to only one in the final result.

4. Take a look at the `input` file for PARATEC. How does it compare to that of
   `1-scf`? What does an NSCF run mean, and why do we do it instead of just
   another SCF?  Find the `k_grid` parameters and compare to those in
   `kgrid.inp`. PARATEC is able to perform the same construction as in
   `kgrid.x`, but for other codes we would need to copy `kgrid.out` to the
   input file. Should you be writing a real or complex wavefunction? Why?
   You can refer to the documentation at
   `http://manual.berkeleygw.org/2.2/paratec-overview/`.

5. When the job is done, compare the k-points generated by PARATEC (listed in
   the `OUT.paratec` file) to those generated by `kgrid.x`. Why do the k-points
   have the weights they do?

6. Compare the symmetry elements reported by PARATEC to those in `kgrid.log`.
   Run `wfn_rho_vxc_info.x WFN > wfn.log` and take a look at what information is
   provided in the `wfn.log` file.
   Compare the symmetry elements here to those from PARATEC (from which they are derived).
   Relate the parameters of the PARATEC calculation to what is in the WFN file.

7. Inspect the `RHO` file with `wfn_rho_vxc_info.x RHO > rho.log`
   and the `VXC` file with `wfn_rho_vxc_info.x VXC > vxc.log`.
   What information is here compared to for `WFN`? Look at the ASCII file `vxc.dat`.
   How do the matrix elements here relate to `WFN` and `VXC`?
   Are they real or complex? Why?
