# Silicon - BGW/Inteqp

In this directory we calculate an interpolated quasiparticle bandstructure for
silicon using the Inteqp code from BerkeleyGW.

Follow these steps:

1. Run the inteqp calculation using
   `sbatch --reservation=vESW_2020_Fri ./01-run_inteqp.run`.

2. Study the input file `inteqp.inp` and compare to the input file description
   in `BSE/absorption.inp` (sections pertaining to inteqp).  Why do we need to
   interpolate rather than just directly run Sigma on these k-points? How is
   the number of coarse points listed determined? Why do we want to use
   symmetries on the coarse grid but not the fine one?

3. What files are linked into this directory? How are they used?

4. Use `degeneracy_check.x` to determine what numbers of conduction and valence
   bands are acceptable with respect to degeneracy from `WFN_co` and `WFN_fi`.
   Are the numbers listed in `inteqp.inp` acceptable? How many bands are
   available in `WFN_co` and `WFN_fi`? How do the degeneracy numbers compare to
   those needed for Epsilon or Sigma? Why?

5. When the job is finished, take a brief look at `inteqp.out`. What warning do
   you see at the end? Look at `dcmat_norm.dat` and `dvmat_norm.dat` to see
   which values are being flagged as less accurate. How could you improve the
   accuracy of the interpolation for these energy levels?

6. Plot the resulting bandstructure.

   1. First, load this module: `module load python`
   2. Then, `./02-plot_bandstructure.py`. Don't worry if you get a message
      about building a font cache as it runs. This will produce `Si_bands.pdf`.
      View with the JupyterLab file browser (or `display Si_bands.pdf`).

7. Using `Si_bands.pdf` and `bandstructure.dat`, find the energy and location
   of the the direct gap and indirect gap, for LDA and GW. What is the valence
   band- width for LDA and GW? How do the band curvatures (effective masses)
   and band topology compare between LDA and GW?
